#ifndef GIVEOPINIONSINK_H
#define GIVEOPINIONSINK_H

#include <QtCore>
#include <mbarcode-qt/plugininterfaces.h>
#include <mbarcode-qt/pluginaction.h>
class Plugin;
class GiveOpinionSink : public QObject, public PluginAction
{
    Q_OBJECT

public:
    // inherited virtuals
    GiveOpinionSink(const PluginInterface *interface);

    QString getName() {return "Informed Individual Give Opinion Sink Plugin";}
    QString getText() {return "Give Opinion with Informed Individual"; }
    QImage getImage();
    bool isReady() {return true;}
    void clickAction(QWidget *parentWindow);
    void setPlugin(Plugin *plugin);
private:
    Plugin *plugin;
    QImage image;
};

#endif // GIVEOPINIONSINK_H
